@@ -6,13 +6,13 @@ var NAVTREEINDEX0 =
 "LREADME.html#autotoc_md0":[10,0],
 "LREADME.html#autotoc_md1":[10,0,0],
 "LREADME.html#basic-build":[10,0,1,2],
-"LREADME.html#bug-reports":[10,0,6],
+"LREADME.html#bug-reports":[10,0,7],
 "LREADME.html#build-with-vmaf":[10,0,1,12],
 "LREADME.html#building-the-library-and-applications":[10,0,1],
 "LREADME.html#coding-style":[10,0,3],
-"LREADME.html#commit-message-hook":[10,0,4,3],
+"LREADME.html#commit-message-hook":[10,0,5,3],
 "LREADME.html#configuration-options":[10,0,1,3],
-"LREADME.html#contributor-agreement":[10,0,4,1],
+"LREADME.html#contributor-agreement":[10,0,5,1],
 "LREADME.html#cross-compiling":[10,0,1,6],
 "LREADME.html#debugging":[10,0,1,5],
 "LREADME.html#downloading-the-test-data":[10,0,2,2],
@@ -23,23 +23,24 @@ var NAVTREEINDEX0 =
 "LREADME.html#extra-build-flags":[10,0,1,11],
 "LREADME.html#get-the-code":[10,0,1,1],
 "LREADME.html#ide-hosted-tests":[10,0,2,1],
-"LREADME.html#incorporating-reviewer-comments":[10,0,4,5],
-"LREADME.html#login-cookie":[10,0,4,0],
+"LREADME.html#incorporating-reviewer-comments":[10,0,5,5],
+"LREADME.html#license-header":[10,0,4],
+"LREADME.html#login-cookie":[10,0,5,0],
 "LREADME.html#microsoft-visual-studio-builds":[10,0,1,8],
 "LREADME.html#prerequisites":[10,0,1,0],
 "LREADME.html#running-test_libaom-directly":[10,0,2,5,0],
 "LREADME.html#running-the-tests-via-the-cmake-build":[10,0,2,5,1],
 "LREADME.html#sanitizers":[10,0,1,7],
 "LREADME.html#sharded-testing":[10,0,2,5],
-"LREADME.html#submitting-patches":[10,0,4],
-"LREADME.html#submitting-your-change":[10,0,4,6],
-"LREADME.html#support":[10,0,5],
+"LREADME.html#submitting-patches":[10,0,5],
+"LREADME.html#submitting-your-change":[10,0,5,6],
+"LREADME.html#support":[10,0,6],
 "LREADME.html#testing-basics":[10,0,2,0],
 "LREADME.html#testing-the-av1-codec":[10,0,2],
-"LREADME.html#testing-your-code":[10,0,4,2],
+"LREADME.html#testing-your-code":[10,0,5,2],
 "LREADME.html#unit-tests":[10,0,2,0,0],
-"LREADME.html#upload-your-change":[10,0,4,4],
-"LREADME.html#viewing-the-status-of-uploaded-changes":[10,0,4,7],
+"LREADME.html#upload-your-change":[10,0,5,4],
+"LREADME.html#viewing-the-status-of-uploaded-changes":[10,0,5,7],
 "LREADME.html#xcode-builds":[10,0,1,9],
 "annotated.html":[13,0],
 "aom_8h.html":[12,1,0,2],
@@ -193,12 +194,12 @@ var NAVTREEINDEX0 =
 "decoder_8h_source.html":[14,0,2,1,0],
 "decoder_guide.html":[7],
 "deprecated.html":[11],
-"dir_093ba9770049e394f80ee43d8cb1dc89.html":[14,0,1],
-"dir_0b150bad2abeb099b7dad7746eb8a42b.html":[14,0,2,2],
-"dir_1d0e02fea82fbc0d5d9ff0bc275d5241.html":[14,0,0],
-"dir_8a19671cc27b434ca698e47fb8974381.html":[14,0,2],
-"dir_ac658dcf456551dfe8b7acbc0b004879.html":[14,0,2,0],
-"dir_aff14c56fff550dc219f04979488c0f8.html":[14,0,2,1],
+"dir_5965606e5c9da3e31d9c062679fc8d28.html":[14,0,2],
+"dir_735bac4053f32b190eb92b624f6f35a9.html":[14,0,2,2],
+"dir_97c83f528edac1fafafcc8a1dacd53c7.html":[14,0,1],
+"dir_b349d27c50b67262c82832e49ec805db.html":[14,0,2,1],
+"dir_e0c7be565db72734186a63b8a6c63a00.html":[14,0,2,0],
+"dir_f014ab2196067aa708ab20dadb42708e.html":[14,0,0],
 "encode__strategy_8h.html":[14,0,2,2,3],
 "encode__strategy_8h_source.html":[14,0,2,2,3],
 "encoder_8h.html":[14,0,2,2,4],
@@ -248,6 +249,5 @@ var NAVTREEINDEX0 =
 "encoder_guide.html#architecture_enc_frame_proc_tf":[8,5,2],
 "encoder_guide.html#architecture_enc_frame_proc_tf_algo":[8,5,2,1],
 "encoder_guide.html#architecture_enc_frame_proc_tf_funcs":[8,5,2,2],
-"encoder_guide.html#architecture_enc_frame_proc_tf_overview":[8,5,2,0],
-"encoder_guide.html#architecture_enc_gf_length":[8,7,2]
+"encoder_guide.html#architecture_enc_frame_proc_tf_overview":[8,5,2,0]
 };
