@@ -1,5 +1,11 @@
 var NAVTREEINDEX8 =
 {
+"structRefreshFrameInfo.html#abda267747d6fc4a0be09eaa6b43f636c":[13,0,115,0],
+"structRefreshFrameInfo.html#af43c353c062e7a0046486cce3d82fa5f":[13,0,115,2],
+"structResizeCfg.html":[13,0,116],
+"structResizeCfg.html#a648d5bb8effb5ece1b5e7abcd4f2a197":[13,0,116,1],
+"structResizeCfg.html#a88f92c8f849f948f7794ba230ed52a25":[13,0,116,2],
+"structResizeCfg.html#adb8460d8997975048cd64a44b37fb1ea":[13,0,116,0],
 "structResizePendingParams.html":[13,0,117],
 "structResizePendingParams.html#a32ee46e7d8f1b44501c388351cbb93c1":[13,0,117,0],
 "structResizePendingParams.html#a51e85984e709e2268fc76acc7505dcd1":[13,0,117,1],
@@ -59,12 +65,12 @@ var NAVTREEINDEX8 =
 "structSgrprojInfo.html#a403c814385e826b519ec252acf8db85a":[13,0,123,0],
 "structSgrprojInfo.html#a654c647c017614714b2ed760ed5418b3":[13,0,123,1],
 "structSuperBlockEnc.html":[13,0,125],
-"structSuperBlockEnc.html#a0165d3ae7bb64dd3c216bb10f03027a4":[13,0,125,5],
+"structSuperBlockEnc.html#a0e0a18f6534a7c694a1544b49f56d3bf":[13,0,125,5],
 "structSuperBlockEnc.html#a11ec5173d2e6f78607276a6770fe180f":[13,0,125,0],
-"structSuperBlockEnc.html#a27704e5db74501d21f069e3bfdeb7656":[13,0,125,3],
-"structSuperBlockEnc.html#a72d94ec63ff40a21455d4a78f83f6610":[13,0,125,4],
+"structSuperBlockEnc.html#a34529f216bc8d1cd51171de3ec66d1f5":[13,0,125,3],
 "structSuperBlockEnc.html#a9685e81f8473b97e9ad9c914636c3491":[13,0,125,1],
 "structSuperBlockEnc.html#ac05e1c9eb1bd5a0b90d9b56437c697a7":[13,0,125,6],
+"structSuperBlockEnc.html#acd28159b28ba8fc88bf6c51fb1f65ab7":[13,0,125,4],
 "structSuperBlockEnc.html#ae6343d8d5c683e41892bc7fc2fc1c889":[13,0,125,2],
 "structSuperResCfg.html":[13,0,126],
 "structSuperResCfg.html#a2c8bec3f18e60f3febe3dc96ccb67b00":[13,0,126,3],
@@ -243,11 +249,5 @@ var NAVTREEINDEX8 =
 "structaom__codec__enc__cfg.html#a76a27f44cded1516803a776a0a7e9038":[12,0,1,5,8],
 "structaom__codec__enc__cfg.html#a7859761b70f5a44005dfd776e7c2f79d":[12,0,1,5,50],
 "structaom__codec__enc__cfg.html#a80cb459c5ef3c7e1516f617c4c9d6eab":[12,0,1,5,3],
-"structaom__codec__enc__cfg.html#a8349dcee2119c7fb3fd15a0ae6fdcf12":[12,0,1,5,6],
-"structaom__codec__enc__cfg.html#a8695946812f24f3719aed80cff00aa29":[12,0,1,5,29],
-"structaom__codec__enc__cfg.html#a877936e8a60207e7eac223811af0c124":[12,0,1,5,40],
-"structaom__codec__enc__cfg.html#a8f3763485bb1f6eea6466b2fe0da2304":[12,0,1,5,11],
-"structaom__codec__enc__cfg.html#a8f8851455e06db026022d4b01671b122":[12,0,1,5,28],
-"structaom__codec__enc__cfg.html#a9217f81f33c62161df9d94e42f2b77c6":[12,0,1,5,19],
-"structaom__codec__enc__cfg.html#aa4d9838419e94e634a02d710da06c842":[12,0,1,5,33]
+"structaom__codec__enc__cfg.html#a8349dcee2119c7fb3fd15a0ae6fdcf12":[12,0,1,5,6]
 };
