@@ -50,7 +50,8 @@ var structAV1__COMP =
     [ "droppable", "structAV1__COMP.html#a9c014587b95805c0d3d3196b3108122e", null ],
     [ "frame_info", "structAV1__COMP.html#a98a22afbd13b9c7a14a1ad51d1bdf415", null ],
     [ "frame_index_set", "structAV1__COMP.html#a61ca5f788df7db66a40f902f8929bf3f", null ],
-    [ "initial_dimensions", "structAV1__COMP.html#a21089e9068a35e00fd998812430b5fa5", null ],
+    [ "data_alloc_width", "structAV1__COMP.html#a7003cb2aa59e7207e246e64465bc64a4", null ],
+    [ "data_alloc_height", "structAV1__COMP.html#a3f184da6e78f358b6c4e8ae744fcd7da", null ],
     [ "initial_mbs", "structAV1__COMP.html#ae99e19b47623d78945a150a2bb590e0e", null ],
     [ "frame_size_related_setup_done", "structAV1__COMP.html#a2728d8d8f677f3a2956a2833d404d2b3", null ],
     [ "last_coded_width", "structAV1__COMP.html#ab777a8c3ab7645c3206edb51cd4d5eeb", null ],
@@ -119,6 +120,7 @@ var structAV1__COMP =
     [ "ducky_encode_info", "structAV1__COMP.html#ae6059c5763ab0b220da971b11b7002f7", null ],
     [ "frames_since_last_update", "structAV1__COMP.html#a0625521a3d2ec6126e96f7539b6bc17b", null ],
     [ "zeromv_skip_thresh_exit_part", "structAV1__COMP.html#a91bbf499df1204752a95d8730108ea2b", null ],
-    [ "image_pyramid_levels", "structAV1__COMP.html#a54cb83d48c9dce7ddc82931e448bc82e", null ],
-    [ "palette_pixel_num", "structAV1__COMP.html#a1190b8a5f0c524ff122e693207e6a9b6", null ]
+    [ "alloc_pyramid", "structAV1__COMP.html#a49f87d79d297a915b8e68909630abcaf", null ],
+    [ "palette_pixel_num", "structAV1__COMP.html#a1190b8a5f0c524ff122e693207e6a9b6", null ],
+    [ "scaled_last_source_available", "structAV1__COMP.html#a852b890830dba74a6f4bce834380424f", null ]
 ];
\ No newline at end of file
